<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use Illuminate\Http\Request;

class CategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $categories = Category::withCount('services')->sort()->paginate(10);
        $allCategories = Category::sort()->get();
        return view('admin.categories.index', compact('categories', 'allCategories'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'description' => 'nullable|string',
            'image' => 'required|image',
            'status' => 'required|boolean',
        ]);
        $category = new Category();
        $category->name = $request->name;
        $category->parent_id = $request->parent_id;
        $category->slug = str()->slug($request->name);
        $category->description = $request->description;
        if ($request->hasFile('image')) {
            $category->image = $request->image->store('categories', 'public');
        }
        $category->status = $request->status;
        $category->save();

        return redirect()->route('a.categories.index')->with('success', 'Category created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(Category $category)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Category $category)
    {
        $allCategories = Category::sort()->get();
        return view('admin.categories.edit', compact('category', 'allCategories'));
    }


    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'description' => 'nullable|string',
            'image' => 'nullable|image',
            'status' => 'required|boolean',
        ]);
        $category = Category::find($id);
        $category->name = $request->name;
        $category->parent_id = $request->parent_id;
        $category->description = $request->description;
        if ($request->hasFile('image')) {
            $category->image = $request->image->store('categories', 'public');
        }
        $category->status = $request->status;
        $category->save();

        return redirect()->route('a.categories.index')->with('success', 'Category updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $category = Category::find($id);
        $category->delete();

        return redirect()->route('a.categories.index')->with('success', 'Category deleted successfully.');
    }
}
