<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Address;
use App\Models\Category;
use App\Models\Service;
use Illuminate\Http\Request;

class ServicesController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $services = Service::sort()->paginate(10);
        return view('admin.services.index', compact('services'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $categories = Category::all();
        return view('admin.services.create', compact('categories'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {

        $request->validate([
            'title' => 'required|string|max:255',
            'description' => 'required|string',
            'name' => 'required|string|max:255',
            'phone' => 'required|string|max:255',
            'email' => 'required|string|email|max:255',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'category_id' => 'required|exists:categories,id',
            'address_line_1' => 'required|string|max:255',
            'address_line_2' => 'nullable|string|max:255',
            'country' => 'required|string|max:255',
            'state' => 'nullable|string|max:255',
            'city' => 'required|string|max:255',
            'zip_code' => 'nullable|string|max:255',
            'latitude' => 'required|string|max:255',
            'longitude' => 'required|string|max:255',
        ]);

        $address = new Address();
        $address->line_1 = $request->address_line_1;
        $address->line_2 = $request->address_line_2;
        $address->country = $request->country;
        $address->state = $request->state;
        $address->city = $request->city;
        $address->zip_code = $request->zip_code;
        $address->latitude = $request->latitude;
        $address->longitude = $request->longitude;
        $address->save();
        $address_id = $address->id;

        $service = new Service();
        $service->name = $request->title;
        $service->description = $request->description;
        $service->user_name = $request->name;
        $service->user_phone = $request->phone;
        $service->user_email = $request->email;
        $service->category_id = $request->category_id;
        if ($request->hasFile('image')) {
            $service->image = $request->file('image')->store('services', 'public');
        }
        $service->address_id = $address_id;
        $service->user_id = auth()->id();
        $service->status = $request->status;
        $service->save();

        return redirect()->route('a.services.index');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $categories = Category::all();
        $service = Service::findOrFail($id);
        return view('admin.services.edit', compact('service', 'categories'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'title' => 'required|string|max:255',
            'description' => 'required|string',
            'name' => 'required|string|max:255',
            'phone' => 'required|string|max:255',
            'email' => 'required|string|email|max:255',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'category_id' => 'required|exists:categories,id',
            'address_line_1' => 'required|string|max:255',
            'address_line_2' => 'nullable|string|max:255',
            'country' => 'required|string|max:255',
            'state' => 'nullable|string|max:255',
            'city' => 'required|string|max:255',
            'zip_code' => 'nullable|string|max:255',
            'latitude' => 'required|string|max:255',
            'longitude' => 'required|string|max:255',
        ]);

        $service = Service::findOrFail($id);

        $address = Address::findOrFail($service->address_id);
        $address->line_1 = $request->address_line_1;
        $address->line_2 = $request->address_line_2;
        $address->country = $request->country;
        $address->state = $request->state;
        $address->city = $request->city;
        $address->zip_code = $request->zip_code;
        $address->latitude = $request->latitude;
        $address->longitude = $request->longitude;
        $address->save();

        $service->name = $request->title;
        $service->description = $request->description;
        $service->user_name = $request->name;
        $service->user_phone = $request->phone;
        $service->user_email = $request->email;
        $service->category_id = $request->category_id;
        if ($request->hasFile('image')) {
            $service->image = $request->file('image')->store('services', 'public');
        }
        $service->status = $request->status;
        $service->save();

        return redirect()->route('a.services.index')->with('success', 'Service updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
}
