<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use App\Models\Token;
use App\Models\TokenTransaction;
use App\Models\Transaction;
use App\Models\Wallet;
use Illuminate\Http\Request;

class TokensController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $token = Token::my()->first();
        $transactions = TokenTransaction::my()->latest()->paginate(10);
        return view('user.tokens.index', compact('token', 'transactions'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'token' => 'required|string',
        ]);

        // deduct money from wallet
        $wallet = Wallet::my()->first();
        // Calculate the amount
        $rate = env('TOKEN_PRICE');
        $amount = $request->token * $rate;
        // dd($amount);

        if ($wallet->balance < $amount) {
            return redirect()->route('u.tokens.index')->with('error', 'You do not have enough money in your wallet.');
        }

        $wallet->update([
            'amount' => $wallet->amount - $amount,
        ]);

        // add wallet transaction
        $transaction = new Transaction();
        $transaction->user_id = auth()->user()->id;
        $transaction->amount = $amount;
        $transaction->type = 'deduct';
        $transaction->status = 1;
        $transaction->save();

        $token = Token::my()->first();
        if ($token) {
            $token->update([
                'token' => $request->token + $token->token,
            ]);
        } else {
            $token = Token::create([
                'user_id' => auth()->user()->id,
                'token' => $request->token,
            ]);
        }

        TokenTransaction::create([
            'user_id' => auth()->user()->id,
            'token' => $token->token,
            'type' => 'add',
            'amount' => 1,
            'status' => 1,
        ]);

        return redirect()->route('u.tokens.index')->with('success', 'Token added successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
}
