<?php

namespace App\Http\Controllers\Web;

use App\Http\Controllers\Controller;
use App\Models\Blog;
use App\Models\Category;
use App\Models\Service;
use Illuminate\Http\Request;

class HomeController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $categories = Category::withCount('services')->active()->get();
        $topBlogs = Blog::with('admin')->active()->latest()->take(3)->get();
        return view('web.home', compact('categories', 'topBlogs'));
    }

    public function blogs()
    {
        $blogs = Blog::active()->latest()->paginate(10);
        return view('web.blogs', compact('blogs'));
    }

    public function blog($slug)
    {
        $blog = Blog::where('slug', $slug)->firstOrFail();
        return view('web.blog', compact('blog'));
    }

    public function about()
    {
        return view('web.home');
    }

    public function contact()
    {
        return view('web.home');
    }

    public function services()
    {
        return view('web.home');
    }

    public function service($slug)
    {
        $service = Service::where('slug', $slug)->firstOrFail();
        return view('web.service', compact('service'));
    }

    public function category(Request $request, $slug)
    {
        $category = Category::where('slug', $slug)->firstOrFail();
        $categories = Category::active()->get();
        $title = $category->name;
        $location = $request->location ?? '';
        $keyword = $request->keyword ?? '';
        $services = Service::where('category_id', $category->id)
            ->where(function ($query) use ($location, $keyword) {
                // if ($location) {
                //     return $query->whereHas('address', function ($query) use ($location) {
                //         return $query->where('city', 'like', "%$location%")->orWhere('state', 'like', "%$location%");
                //     });
                // }
                if ($keyword) {
                    return $query->where('name', 'like', "%$keyword%");
                }
            })
            ->active()->paginate(10);
        return view('web.category', compact('category', 'services', 'title', 'location', 'keyword', 'categories'));
    }
}
