<?php

namespace App\Http\Livewire;

use App\Libraries\Fcm;
use App\Models\Message;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Http;
use Livewire\Component;
use Livewire\WithFileUploads;

class Messages extends Component
{
    use WithFileUploads;

    public $message, $file;
    public $users;
    public $active, $chatMessages, $chatWith;

    public function mount()
    {
        $this->message = '';
        $this->file = '';

        $this->users = User::whereHas('messages', function ($query) {
            $query->where('sender_id', auth()->user()->id)
                ->orWhere('receiver_id', auth()->user()->id);
        })
            ->with('message')
            ->get();
        $this->chatMessages = Message::where('sender_id', 'xxx')->get();
    }

    public function render()
    {
        return view('livewire.messages');
    }

    public function chat($user_id)
    {
        $this->active = $user_id;
        $this->chatWith = User::find($user_id);
        $this->chatMessages = Message::where(function ($query) use ($user_id) {
            $query->where('sender_id', auth()->user()->id)
                ->where('receiver_id', $user_id);
        })
            ->orWhere(function ($query) use ($user_id) {
                $query->where('sender_id', $user_id)
                    ->where('receiver_id', auth()->user()->id);
            })
            ->get();
    }

    public function loading()
    {
        $this->chat($this->active);
    }

    public function call()
    {
        $this->sendMessage('Calling...');
    }

    public function videoCall()
    {
        $METERED_DOMAIN = env('METERED_DOMAIN');
        $METERED_SECRET_KEY = env('METERED_SECRET_KEY');


        // Contain the logic to create a new meeting
        $response = Http::post("https://{$METERED_DOMAIN}/api/v1/room?secretKey={$METERED_SECRET_KEY}", [
            'autoJoin' => true
        ]);

        $roomName = $response->json("roomName");

        $uniqueCallKey = route('u.meeting.join', $roomName);
        // $this->receiver->notify(new \App\Notifications\MakingCall($this->receiver, $uniqueCallKey));
        $message = 'I am calling you <br> Join this call using this link: <a class="btn btn-info btn-sm" href="' . $uniqueCallKey . '">Join Now</a>';
        $fcm = new Fcm();
        $notification = [
            'title' => 'You have a new call',
            'body' => Auth::user()->name . ' is calling you. Tap to join the call.',
            'icon' => 'https://www.gravatar.com/avatar/' . md5(strtolower(trim(Auth::user()->email))) . '?s=160&d=mm&r=g',
            'click_action' => route('u.meeting.join', $roomName)
        ];
        // $fcm->sendNotification($this->receiver, $notification);
        $this->sendMessage($message);
    }

    public function uploadFile()
    {
        $this->validate([
            'file' => 'required|mimes:pdf,doc,docx,xls,xlsx,ppt,pptx,txt,zip,rar,jpg,jpeg,png|max:2048'
        ]);
        $messageModel = new Message();
        $messageModel->sender_id = auth()->user()->id;
        $messageModel->receiver_id = 1;
        $messageModel->file = $this->file->store('chat', 'public');
        $messageModel->save();
        $this->file = '';
        $this->chat($this->active);
    }

    public function sendMessage($message = '')
    {
        if ($message != '') {
            $messageModel = new Message();
            $messageModel->sender_id = auth()->user()->id;
            $messageModel->receiver_id = 1;
            $messageModel->message = $message;
            $messageModel->save();
        } else {
            $this->validate([
                'message' => 'required'
            ]);

            $messageModel = new Message();
            $messageModel->sender_id = auth()->user()->id;
            $messageModel->receiver_id = 1;
            $messageModel->message = $this->message;
            if ($this->file) {
                $this->file->store('chat', 'public');
            }
            $messageModel->save();
            $this->message = '';
        }

        $fcm = new Fcm();
        $notification = [
            'title' => 'You have a new call',
            'body' => Auth::user()->name . ' has sent you a message. Tap to view.',
            'icon' => 'https://www.gravatar.com/avatar/' . md5(strtolower(trim(Auth::user()->email))) . '?s=160&d=mm&r=g',
        ];
        // $fcm->sendNotification($this->active, $notification);
        $this->chat($this->active);
    }
}
