<?php

namespace App\Http\Livewire;

use App\Jobs\AssignLeadToUsers;
use App\Libraries\Sms;
use App\Models\Category;
use App\Models\Lead;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;
use Livewire\Component;

class VerifyMobile extends Component
{
    protected $listeners = [
        'openVerifyMobileModal' => 'done',
    ];

    public $show;
    public $otpShow = false;
    public $mobile;
    public $otp;
    public $success = "";
    public $error = "";
    public $sentOTP = "";
    public $location = "";
    public $keyword = "";
    public $category = "";
    public $lead_id = null;
    public $use_whatsapp = false;

    public $fullname, $email, $register_user = false, $password, $password_confirmation;
    public $loggedIn = false;

    public function done($location, $keyword, $category, $lead_id = null)
    {
        $this->location = $location;
        $this->keyword = $keyword;
        $this->category = $category;
        $this->show = true;
        $this->success = "";
        $this->mobile = "";
        $this->otp = "";
        $this->otpShow = false;
        $this->lead_id = $lead_id;
    }

    public function render()
    {
        return view('livewire.verify-mobile');
    }

    public function mount()
    {
        $this->show = true;
        $this->success = "";
        $this->mobile = "";
        $this->otp = "";
        $this->otpShow = false;

        if (Auth::check()) {
            $this->fullname = Auth::user()->name;
            $this->email = Auth::user()->email;
            $this->mobile = Auth::user()->phone;
            $this->loggedIn = true;
        }
    }

    function resendOtp()
    {
        $this->validate([
            'mobile' => 'string',
        ]);
        $this->sendOtpAPI($this->mobile, $this->sentOTP);
        $this->success = "We have sent you a new OTP " . $this->sentOTP;
        $this->sentOTP = rand(100000, 999999);
    }

    function sendOtp()
    {
        $this->validate([
            'mobile' => 'string',
        ]);
        if (Auth::check()) {
            $this->validate([
                'mobile' => 'required',
            ]);
            $this->sentOTP = rand(100000, 999999);
            $user = Auth::user();
            $array = [
                'name' => $user->name,
                'email' => $user->email,
                'phone' => $user->mobile,
                'search_query' => $this->keyword,
                'locale' => 'en',
                'date' => null,
                'time' => null,
                'service_id' => null,
                'category_id' => $this->category,
                'title' => $this->keyword,
                'enquiry' => $this->keyword,
            ];
            $lead_id = $this->saveLead($array);

            $this->sendOtpAPI($this->mobile, $this->sentOTP);
            $this->success = "OTP has been sent to your mobile number " . $this->sentOTP;
            $this->otpShow = true;
        } else {
            if ($this->register_user) {
                $this->validate([
                    'fullname' => 'required',
                    'email' => 'required|email|unique:users,email',
                    'mobile' => 'required|unique:users,phone',
                    'password' => 'required|min:8',
                ]);
                // check if user exists
                $checkUser = User::where('email', $this->email)->first();
                if ($checkUser) {
                    $this->error = "User already exists";
                    return;
                } else {
                    // check password and password_confirmation
                    if ($this->password != $this->password_confirmation) {
                        $this->error = "Password and Confirm Password does not match";
                        return;
                    } else {
                        $user = User::create([
                            'name' => $this->fullname,
                            'email' => $this->email,
                            'password' => $this->password,
                            'phone' => $this->mobile,
                        ]);
                        Auth::login($user);
                        $this->loggedIn = true;
                    }
                }
            } else {
                $this->validate([
                    'fullname' => 'required',
                    'email' => 'required|email',
                    'mobile' => 'required',
                ]);
            }
            $array = [
                'name' => $this->fullname,
                'email' => $this->email,
                'phone' => $this->mobile,
                'search_query' => $this->keyword,
                'locale' => 'en',
                'date' => null,
                'time' => null,
                'service_id' => null,
                'category_id' => $this->category,
                'title' => $this->keyword,
                'enquiry' => $this->keyword,
            ];
            $lead_id = $this->saveLead($array);
            $this->sentOTP = rand(100000, 999999);
            $this->sendOtpAPI($this->mobile, $this->sentOTP);
            $this->success = "OTP has been sent to your mobile number " . $this->sentOTP;
            $this->otpShow = true;
        }
    }

    function verifyOtp()
    {
        $this->validate([
            'otp' => 'required|digits:6',
        ]);

        if ($this->otp == $this->sentOTP) {
            $this->success = "OTP verified successfully";
            $this->otpShow = false;
            // save the state that the user has verified his mobile number
            Session::put('mobileVerified', true);
            Session::put('mobile', $this->mobile);
            if (Auth::check()) {
                Auth::user()->update([
                    'phone_verified_at' => now(),
                    'phone' => $this->mobile,
                ]);
            }
            // dd($this->location, $this->keyword);
            $this->emit('otpVerified', $this->location, $this->keyword, $this->category);
            $tCat = Category::find($this->category);
            return redirect()->route('category', ['location' => $this->location, 'keyword' => $this->keyword, 'category' => $tCat->slug]);
        } else {
            $this->error = "OTP is incorrect";
        }
    }

    public function sendOtpAPI($mobile, $otp)
    {
        $hasCode = substr($mobile, 0, 4);
        if ($hasCode != '+91') {
            // remove the first 0 if it exists
            if (substr($mobile, 0, 1) == '0')
                $mobile = substr($mobile, 1);
            $mobile = '+91' . $mobile;
        }
        // dd($mobile);
        (new Sms($mobile, "Please use this code to verify your phone number: {$otp}"))->send();

        // if ($this->use_whatsapp == true) {
        //     $message = $client->messages->create(
        //         "whatsapp:" . $mobile,
        //         array(
        //             "from" => config('twilio.whatsapp_from'),
        //             "body" => "Please use this code to verify your phone number: {$otp}"
        //         )
        //     );

        //     Log::info($message->sid);
        //     Log::info($message);
        // } else {

        //     // Use the Client to make requests to the Twilio REST API
        //     $client->messages->create(
        //         // The number you'd like to send the message to
        //         $mobile,
        //         [
        //             "messagingServiceSid" => config('twilio.from'),
        //             'body' => "Please use this code to verify your phone number: {$otp}"
        //         ]
        //     );
        // }
    }

    public function saveLead($array)
    {
        $lead = new Lead();
        $lead->name = $array['name'];
        $lead->email = $array['email'];
        $lead->phone = $array['phone'];
        $lead->user_id = Auth::id();
        $lead->search_query = $array['search_query'];
        $lead->service_id = $array['service_id'];
        $lead->category_id = $array['category_id'];
        $lead->title = $array['title'];
        $lead->description = $array['enquiry'];
        $lead->save();

        // Dispatch the job
        $assign = new AssignLeadToUsers();
        dispatch($assign);

        return $lead->id;
    }
}
