<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Cviebrock\EloquentSluggable\Sluggable;
use Illuminate\Database\Eloquent\Concerns\HasUuids;

class Service extends Model
{
    use HasFactory, Sluggable, HasUuids;

    protected $fillable = [
        'name',
        'slug',
        'description',
        'image',
        'status',
        'category_id',
        'user_id',
        'user_name',
        'user_email',
        'user_phone',
        'address_id',
        'average_rating',
        'total_reviews',
    ];

    public function sluggable(): array
    {
        return [
            'slug' => [
                'source' => 'name'
            ]
        ];
    }

    public function category()
    {
        return $this->belongsTo(Category::class);
    }

    public function address()
    {
        return $this->belongsTo(Address::class);
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function reviews()
    {
        return $this->hasMany(Review::class);
    }

    public function scopeActive($query)
    {
        return $query->where('status', 1);
    }

    public function scopeMy($query)
    {
        return $query->where('user_id', auth()->id());
    }

    public function scopeSort($query)
    {
        return $query->orderBy('created_at', 'desc');
    }
}
