<?php

namespace App\Models;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticatable implements MustVerifyEmail
{
    use HasApiTokens, HasFactory, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'email',
        'password',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    // Insert Wallet and token when new user created
    protected static function boot()
    {
        parent::boot();

        static::created(function ($user) {
            $user->wallet()->create([
                'balance' => 0,
            ]);
            $user->token()->create([
                'token' => 0,
            ]);
        });
    }

    public function messages()
    {
        return $this->hasMany(Message::class, 'sender_id');
    }

    public function message()
    {
        return $this->hasOne(Message::class, 'receiver_id')->latest();
    }

    public function wallet()
    {
        return $this->hasOne(Wallet::class);
    }

    public function token()
    {
        return $this->hasOne(Token::class);
    }

    public function deviceTokens(): HasMany
    {
        return $this->hasMany(DeviceToken::class);
    }

    public function routeNotificationForFCM($notification): string|array|null
    {
        return $this->deviceTokens->pluck('token')->toArray();
    }

    /**
     * Optional method to determine which message target to use
     * We will use TOKEN type when not specified
     * @see \Kreait\Firebase\Messaging\MessageTarget::TYPES
     */
    public function routeNotificationForFCMTargetType($notification): ?string
    {
        return \Kreait\Firebase\Messaging\MessageTarget::TOKEN;
    }

    /**
     * Optional method to determine which Firebase project to use
     * We will use default project when not specified
     */
    public function routeNotificationForFCMProject($notification): ?string
    {
        return config('firebase.default');
    }
}
