<?php

use App\Http\Controllers\FirebaseController;
use App\Http\Controllers\User\ProfileController;
use App\Http\Controllers\User\DashboardController;
use App\Http\Controllers\User\LeadsController;
use App\Http\Controllers\User\MessagesController;
use App\Http\Controllers\User\ServicesController;
use App\Http\Controllers\User\TokensController;
use App\Http\Controllers\User\VideoChatController;
use App\Http\Controllers\User\WalletsController;
use App\Http\Controllers\Web\HomeController;
use App\Libraries\Sms;
use Illuminate\Support\Facades\Route;
use Vonage\Client;
use Vonage\Messages\Channel\WhatsApp\WhatsAppText;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::get('/a', function () {
    return (new Sms('917454947738', '844552'))->send();
});


Route::get('/', [HomeController::class, 'index'])->name('home');
Route::get('/about', [HomeController::class, 'about'])->name('about');
Route::get('/contact', [HomeController::class, 'contact'])->name('contact');
Route::get('/services', [HomeController::class, 'services'])->name('services');
Route::get('/service/{service}', [HomeController::class, 'service'])->name('service');
Route::get('/category/{category}', [HomeController::class, 'category'])->name('category');
Route::get('/blogs', [HomeController::class, 'blogs'])->name('blogs');
Route::get('/blog/{blog}', [HomeController::class, 'blog'])->name('blog.show');

Route::middleware('auth:web', 'verified')->name('u.')->prefix('account')->group(function () {
    Route::controller(ProfileController::class)->name('profile.')->group(function () {
        Route::get('/profile', 'edit')->name('edit');
        Route::patch('/profile', 'update')->name('update');
        Route::delete('/profile', 'destroy')->name('destroy');
    });

    Route::get('/', [DashboardController::class, 'index'])->name('dashboard');
    Route::resource('services', ServicesController::class);
    Route::resource('leads', LeadsController::class);
    Route::post('leads/{lead}/purchase', [LeadsController::class, 'purchase'])->name('leads.purchase');
    Route::resource('messages', MessagesController::class);
    Route::resource('wallet', WalletsController::class);
    Route::resource('tokens', TokensController::class);

    Route::get('/meeting', [VideoChatController::class, 'index'])->name('meeting');
    Route::post("/meeting/create", [VideoChatController::class, 'createMeeting'])->name("meeting.create");
    Route::post("/meeting/validate", [VideoChatController::class, 'validateMeeting'])->name("meeting.validate");
    Route::get("/meeting/{meetingId}", [VideoChatController::class, 'meeting'])->name("meeting.join");

    Route::post('firebase/token', [FirebaseController::class, 'storeToken'])->name('firebase.token');
});
Route::get('/offline', function () {
    return abort(404);
});
require __DIR__ . '/auth.php';
require __DIR__ . '/admin-auth.php';
require __DIR__ . '/admin.php';
